==> qtjambi-quick3d-debuginfo-windows-x64-6.6.1.jar: sources/QtJambiQuick3D/QQuick3DGeometry_TargetAttribute_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQuick3D/qquick3dgeometry.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QQuick3DGeometry_TargetAttribute(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQuick3DGeometry::TargetAttribute")
    QQuick3DGeometry::TargetAttribute *_ptr = reinterpret_cast<QQuick3DGeometry::TargetAttribute *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QQuick3DGeometry_TargetAttribute_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QQuick3DGeometry::TargetAttribute *__qt_this = new(__qtjambi_ptr) QQuick3DGeometry::TargetAttribute();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QQuick3DGeometry::TargetAttribute
void __qt_destruct_QQuick3DGeometry_TargetAttribute(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQuick3DGeometry::TargetAttribute")
    reinterpret_cast<QQuick3DGeometry::TargetAttribute*>(ptr)->~TargetAttribute();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQuick3DGeometry::TargetAttribute::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024TargetAttribute_initialize_1native__Lio_qt_quick3d_QQuick3DGeometry_00024TargetAttribute_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQuick3DGeometry::TargetAttribute::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQuick3DGeometry_TargetAttribute_0, sizeof(QQuick3DGeometry::TargetAttribute), typeid(QQuick3DGeometry::TargetAttribute), false, &deleter_QQuick3DGeometry_TargetAttribute, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024TargetAttribute_setAttr_1native_1cref_1QQuick3DGeometry_1Attribute__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID attr0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuick3DGeometry::TargetAttribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::TargetAttribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QQuick3DGeometry::Attribute& __qt_attr0 = QtJambiAPI::valueReferenceFromNativeId<QQuick3DGeometry::Attribute>(attr0);
        __qt_this->attr = __qt_attr0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024TargetAttribute_attr_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuick3DGeometry::TargetAttribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::TargetAttribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QQuick3DGeometry::Attribute&  __qt_value = __qt_this->attr;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024TargetAttribute_setStride_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint stride0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuick3DGeometry::TargetAttribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::TargetAttribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->stride = static_cast<int>(stride0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024TargetAttribute_stride_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuick3DGeometry::TargetAttribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::TargetAttribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->stride;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024TargetAttribute_setTargetId_1native_1quint32__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint targetId0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuick3DGeometry::TargetAttribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::TargetAttribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->targetId = static_cast<quint32>(targetId0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024TargetAttribute_targetId_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuick3DGeometry::TargetAttribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::TargetAttribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        quint32  __qt_value = __qt_this->targetId;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024TargetAttribute_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QQuick3DGeometry::TargetAttribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::TargetAttribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QQuick3DGeometry_TargetAttribute(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QQuick3DGeometry::TargetAttribute>("QQuick3DGeometry::TargetAttribute", "io/qt/quick3d/QQuick3DGeometry$TargetAttribute");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QQuick3DGeometry_TargetAttribute, {
        ConstructorInfo(&__qt_construct_QQuick3DGeometry_TargetAttribute_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QQuick3DGeometry_TargetAttribute);
    registerMetaType<QQuick3DGeometry::TargetAttribute>("QQuick3DGeometry::TargetAttribute");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-quick3d-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiQuick3D/QQuick3DGeometry_TargetAttribute_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQuick3D/qquick3dgeometry.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QQuick3DGeometry_TargetAttribute(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQuick3DGeometry::TargetAttribute")
    QQuick3DGeometry::TargetAttribute *_ptr = reinterpret_cast<QQuick3DGeometry::TargetAttribute *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new TargetAttribute()
void __qt_construct_QQuick3DGeometry_TargetAttribute(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct TargetAttribute()")
    Q_UNUSED(__java_arguments)
    QQuick3DGeometry::TargetAttribute *__qt_this = new(__qtjambi_ptr) QQuick3DGeometry::TargetAttribute();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QQuick3DGeometry::TargetAttribute::TargetAttribute()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024TargetAttribute_initialize_1native__Lio_qt_quick3d_QQuick3DGeometry_00024TargetAttribute_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQuick3DGeometry::TargetAttribute::TargetAttribute()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQuick3DGeometry_TargetAttribute, sizeof(QQuick3DGeometry::TargetAttribute), typeid(QQuick3DGeometry::TargetAttribute), false, &deleter_QQuick3DGeometry_TargetAttribute, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new TargetAttribute(QQuick3DGeometry::TargetAttribute)
void __qt_construct_QQuick3DGeometry_TargetAttribute_cref_QQuick3DGeometry_TargetAttribute(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct TargetAttribute(QQuick3DGeometry::TargetAttribute)")
    jobject other0 = __java_arguments[0].l;
    const QQuick3DGeometry::TargetAttribute& __qt_other0 = qtjambi_cast<const QQuick3DGeometry::TargetAttribute& >(__jni_env, other0);
    QQuick3DGeometry::TargetAttribute *__qt_this = new(__qtjambi_ptr) QQuick3DGeometry::TargetAttribute(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QQuick3DGeometry::TargetAttribute::TargetAttribute(QQuick3DGeometry::TargetAttribute)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024TargetAttribute_initialize_1native__Lio_qt_quick3d_QQuick3DGeometry_00024TargetAttribute_2Lio_qt_quick3d_QQuick3DGeometry_00024TargetAttribute_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQuick3DGeometry::TargetAttribute::TargetAttribute(QQuick3DGeometry::TargetAttribute)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQuick3DGeometry_TargetAttribute_cref_QQuick3DGeometry_TargetAttribute, sizeof(QQuick3DGeometry::TargetAttribute), typeid(QQuick3DGeometry::TargetAttribute), false, &deleter_QQuick3DGeometry_TargetAttribute, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new TargetAttribute{quint32,QQuick3DGeometry::Attribute,int}
void __qt_construct_QQuick3DGeometry_TargetAttribute_quint32_QQuick3DGeometry_Attribute_int(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct TargetAttribute{quint32,QQuick3DGeometry::Attribute,int}")
    jint targetId0 = __java_arguments[0].i;
    Q_UNUSED(targetId0)
    jobject attr1 = __java_arguments[1].l;
    QQuick3DGeometry::Attribute __qt_attr1 = qtjambi_cast<QQuick3DGeometry::Attribute >(__jni_env, attr1);
    jint stride2 = __java_arguments[2].i;
    Q_UNUSED(stride2)
    QQuick3DGeometry::TargetAttribute *__qt_this = new(__qtjambi_ptr) QQuick3DGeometry::TargetAttribute{static_cast<quint32>(targetId0), __qt_attr1, static_cast<int>(stride2)};
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QQuick3DGeometry::TargetAttribute::TargetAttribute{quint32,QQuick3DGeometry::Attribute,int}
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024TargetAttribute_initialize_1native__Lio_qt_quick3d_QQuick3DGeometry_00024TargetAttribute_2ILio_qt_quick3d_QQuick3DGeometry_00024Attribute_2I)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jint targetId0,
 jobject attr1,
 jint stride2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQuick3DGeometry::TargetAttribute::TargetAttribute{quint32,QQuick3DGeometry::Attribute,int}")
    QTJAMBI_TRY {
        jvalue arguments[3];
        arguments[0].i = targetId0;
        arguments[1].l = attr1;
        arguments[2].i = stride2;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQuick3DGeometry_TargetAttribute_quint32_QQuick3DGeometry_Attribute_int, sizeof(QQuick3DGeometry::TargetAttribute), typeid(QQuick3DGeometry::TargetAttribute), false, &deleter_QQuick3DGeometry_TargetAttribute, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QQuick3DGeometry::TargetAttribute
void __qt_destruct_QQuick3DGeometry_TargetAttribute(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQuick3DGeometry::TargetAttribute")
    reinterpret_cast<QQuick3DGeometry::TargetAttribute*>(ptr)->~TargetAttribute();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024TargetAttribute_setAttr_1native_1cref_1QQuick3DGeometry_1Attribute__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID attr0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuick3DGeometry::TargetAttribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::TargetAttribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QQuick3DGeometry::Attribute& __qt_attr0 = QtJambiAPI::valueReferenceFromNativeId<QQuick3DGeometry::Attribute>(attr0);
        __qt_this->attr = __qt_attr0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024TargetAttribute_attr_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuick3DGeometry::TargetAttribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::TargetAttribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QQuick3DGeometry::Attribute&  __qt_value = __qt_this->attr;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024TargetAttribute_setStride_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint stride0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuick3DGeometry::TargetAttribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::TargetAttribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->stride = static_cast<int>(stride0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024TargetAttribute_stride_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuick3DGeometry::TargetAttribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::TargetAttribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->stride;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024TargetAttribute_setTargetId_1native_1quint32__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint targetId0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuick3DGeometry::TargetAttribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::TargetAttribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->targetId = static_cast<quint32>(targetId0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024TargetAttribute_targetId_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuick3DGeometry::TargetAttribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::TargetAttribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        quint32  __qt_value = __qt_this->targetId;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024TargetAttribute_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QQuick3DGeometry::TargetAttribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::TargetAttribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QQuick3DGeometry_TargetAttribute(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QQuick3DGeometry::TargetAttribute>("QQuick3DGeometry::TargetAttribute", "io/qt/quick3d/QQuick3DGeometry$TargetAttribute");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QQuick3DGeometry_TargetAttribute, {
        ConstructorInfo(&__qt_construct_QQuick3DGeometry_TargetAttribute, nullptr)
       ,ConstructorInfo(&__qt_construct_QQuick3DGeometry_TargetAttribute_cref_QQuick3DGeometry_TargetAttribute, "Lio/qt/quick3d/QQuick3DGeometry$TargetAttribute;")
       ,ConstructorInfo(&__qt_construct_QQuick3DGeometry_TargetAttribute_quint32_QQuick3DGeometry_Attribute_int, "ILio/qt/quick3d/QQuick3DGeometry$Attribute;I")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QQuick3DGeometry_TargetAttribute);
    registerMetaType<QQuick3DGeometry::TargetAttribute>("QQuick3DGeometry::TargetAttribute");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
